package x509

  1. Overview
  2. Docs

Module Distinguished_name.Organization_name

The module type for organization name.

The variant of string tags.

type t

The type of an encoded value.

val v : ?encoding:encoding -> string -> t

v ~encoding s constructs an attribute value from the string contents s in encoding, without validation, transcoding or normalization. The default is UTF8String for DirectoryString attributes, PrintableString for country names and serial numbers, and IA5String for email addresses.

val of_encoded : encoding Encoded_string.t -> t

of_encoded value retains the encoding and content octets.

val encoded : t -> encoding Encoded_string.t

encoded t is the Encoded_string.t of t.

val to_string : t -> string

to_string t is the content of t in its declared encoding, not necessarily UTF-8. No transcoding is performed: a BMPString containing "A" is returned as "\x00A".